@@ -2,18 +2,19 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import logging
-
-from typing import Optional, Dict, Any, Union, Iterator
+from typing import (
+    Any, Iterator, Optional, Union,
+)
 
 from databuilder.models.dashboard.dashboard_metadata import DashboardMetadata
-from databuilder.models.neo4j_csv_serde import (
-    Neo4jCsvSerializable, NODE_LABEL, NODE_KEY, RELATION_START_KEY, RELATION_END_KEY, RELATION_START_LABEL,
-    RELATION_END_LABEL, RELATION_TYPE, RELATION_REVERSE_TYPE)
+from databuilder.models.graph_node import GraphNode
+from databuilder.models.graph_relationship import GraphRelationship
+from databuilder.models.graph_serializable import GraphSerializable
 
 LOGGER = logging.getLogger(__name__)
 
 
-class DashboardExecution(Neo4jCsvSerializable):
+class DashboardExecution(GraphSerializable):
     """
     A model that encapsulate Dashboard's execution timestamp in epoch and execution state
     """
@@ -46,40 +47,45 @@ class DashboardExecution(Neo4jCsvSerializable):
         self._node_iterator = self._create_node_iterator()
         self._relation_iterator = self._create_relation_iterator()
 
-    def create_next_node(self) -> Union[Dict[str, Any], None]:
+    def create_next_node(self) -> Union[GraphNode, None]:
         try:
             return next(self._node_iterator)
         except StopIteration:
             return None
 
-    def _create_node_iterator(self) -> Iterator[Dict[str, Any]]:  # noqa: C901
-        yield {
-            NODE_LABEL: DashboardExecution.DASHBOARD_EXECUTION_LABEL,
-            NODE_KEY: self._get_last_execution_node_key(),
-            'timestamp': self._execution_timestamp,
-            'state': self._execution_state
-        }
+    def _create_node_iterator(self) -> Iterator[GraphNode]:
+        node = GraphNode(
+            key=self._get_last_execution_node_key(),
+            label=DashboardExecution.DASHBOARD_EXECUTION_LABEL,
+            attributes={
+                'timestamp': self._execution_timestamp,
+                'state': self._execution_state
+            }
+        )
+        yield node
 
-    def create_next_relation(self) -> Union[Dict[str, Any], None]:
+    def create_next_relation(self) -> Union[GraphRelationship, None]:
         try:
             return next(self._relation_iterator)
         except StopIteration:
             return None
 
-    def _create_relation_iterator(self) -> Iterator[Dict[str, Any]]:
-        yield {
-            RELATION_START_LABEL: DashboardMetadata.DASHBOARD_NODE_LABEL,
-            RELATION_END_LABEL: DashboardExecution.DASHBOARD_EXECUTION_LABEL,
-            RELATION_START_KEY: DashboardMetadata.DASHBOARD_KEY_FORMAT.format(
+    def _create_relation_iterator(self) -> Iterator[GraphRelationship]:
+        relationship = GraphRelationship(
+            start_label=DashboardMetadata.DASHBOARD_NODE_LABEL,
+            start_key=DashboardMetadata.DASHBOARD_KEY_FORMAT.format(
                 product=self._product,
                 cluster=self._cluster,
                 dashboard_group=self._dashboard_group_id,
                 dashboard_name=self._dashboard_id
             ),
-            RELATION_END_KEY: self._get_last_execution_node_key(),
-            RELATION_TYPE: DashboardExecution.DASHBOARD_EXECUTION_RELATION_TYPE,
-            RELATION_REVERSE_TYPE: DashboardExecution.EXECUTION_DASHBOARD_RELATION_TYPE
-        }
+            end_label=DashboardExecution.DASHBOARD_EXECUTION_LABEL,
+            end_key=self._get_last_execution_node_key(),
+            type=DashboardExecution.DASHBOARD_EXECUTION_RELATION_TYPE,
+            reverse_type=DashboardExecution.EXECUTION_DASHBOARD_RELATION_TYPE,
+            attributes={}
+        )
+        yield relationship
 
     def _get_last_execution_node_key(self) -> str:
         return DashboardExecution.DASHBOARD_EXECUTION_KEY_FORMAT.format(
@@ -91,12 +97,6 @@ class DashboardExecution(Neo4jCsvSerializable):
         )
 
     def __repr__(self) -> str:
-        return 'DashboardExecution({!r}, {!r}, {!r}, {!r}, {!r}, {!r}, {!r})'.format(
-            self._dashboard_group_id,
-            self._dashboard_id,
-            self._execution_timestamp,
-            self._execution_state,
-            self._execution_id,
-            self._product,
-            self._cluster
-        )
+        return f'DashboardExecution({self._dashboard_group_id!r}, {self._dashboard_id!r}, ' \
+               f'{self._execution_timestamp!r}, {self._execution_state!r}, ' \
+               f'{self._execution_id!r}, {self._product!r}, {self._cluster!r})'
