@@ -157,7 +157,7 @@ class ColumnMetadata:
     COLUMN_NODE_LABEL = 'Column'
     COLUMN_KEY_FORMAT = '{db}://{cluster}.{schema}/{tbl}/{col}'
     COLUMN_NAME = 'name'
-    COLUMN_TYPE = 'type'
+    COLUMN_TYPE = 'col_type'
     COLUMN_ORDER = 'sort_order'
     COLUMN_DESCRIPTION = 'description'
     COLUMN_DESCRIPTION_FORMAT = '{db}://{cluster}.{schema}/{tbl}/{col}/{description_id}'
@@ -364,7 +364,8 @@ class TableMetadata(GraphSerializable):
                     start_label=ColumnMetadata.COLUMN_NODE_LABEL,
                     start_key=self._get_col_key(col),
                     badges=col.badges)
-                for node in col_badge_metadata.create_nodes():
+                badge_nodes = col_badge_metadata.get_badge_nodes()
+                for node in badge_nodes:
                     yield node
 
         # Database, cluster, schema
@@ -472,7 +473,7 @@ class TableMetadata(GraphSerializable):
                 badge_metadata = BadgeMetadata(start_label=ColumnMetadata.COLUMN_NODE_LABEL,
                                                start_key=self._get_col_key(col),
                                                badges=col.badges)
-                badge_relations = badge_metadata.create_relation()
+                badge_relations = badge_metadata.get_badge_relations()
                 for relation in badge_relations:
                     yield relation
 
