@@ -1,6 +1,6 @@
 # Copyright Contributors to the Amundsen project.
 # SPDX-License-Identifier: Apache-2.0
-from typing import List, Optional
+from typing import Iterator, Optional
 
 from databuilder.models.graph_node import GraphNode
 from databuilder.models.graph_relationship import GraphRelationship
@@ -15,7 +15,7 @@ class TableColumnStats(GraphSerializable):
     """
     LABEL = 'Stat'
     KEY_FORMAT = '{db}://{cluster}.{schema}' \
-                 '/{table}/{col}/{stat_name}/'
+                 '/{table}/{col}/{stat_type}/'
     STAT_Column_RELATION_TYPE = 'STAT_OF'
     Column_STAT_RELATION_TYPE = 'STAT'
 
@@ -40,10 +40,10 @@ class TableColumnStats(GraphSerializable):
         self.start_epoch = start_epoch
         self.end_epoch = end_epoch
         self.cluster = cluster
-        self.stat_name = stat_name
+        self.stat_type = stat_name
         self.stat_val = str(stat_val)
-        self._node_iter = iter(self.create_nodes())
-        self._relation_iter = iter(self.create_relation())
+        self._node_iter = self._create_node_iterator()
+        self._relation_iter = self._create_relation_iterator()
 
     def create_next_node(self) -> Optional[GraphNode]:
         # return the string representation of the data
@@ -64,7 +64,7 @@ class TableColumnStats(GraphSerializable):
                                                   schema=self.schema,
                                                   table=self.table,
                                                   col=self.col_name,
-                                                  stat_name=self.stat_name)
+                                                  stat_type=self.stat_type)
 
     def get_col_key(self) -> str:
         # no cluster, schema info from the input
@@ -74,9 +74,9 @@ class TableColumnStats(GraphSerializable):
                                                        tbl=self.table,
                                                        col=self.col_name)
 
-    def create_nodes(self) -> List[GraphNode]:
+    def _create_node_iterator(self) -> Iterator[GraphNode]:
         """
-        Create a list of Neo4j node records
+        Create a table stat node
         :return:
         """
         node = GraphNode(
@@ -84,17 +84,16 @@ class TableColumnStats(GraphSerializable):
             label=TableColumnStats.LABEL,
             attributes={
                 'stat_val': self.stat_val,
-                'stat_name': self.stat_name,
+                'stat_type': self.stat_type,
                 'start_epoch': self.start_epoch,
                 'end_epoch': self.end_epoch,
             }
         )
-        results = [node]
-        return results
+        yield node
 
-    def create_relation(self) -> List[GraphRelationship]:
+    def _create_relation_iterator(self) -> Iterator[GraphRelationship]:
         """
-        Create a list of relation map between table stat record with original hive table
+        Create relation map between table stat record with original hive table
         :return:
         """
         relationship = GraphRelationship(
@@ -106,5 +105,4 @@ class TableColumnStats(GraphSerializable):
             reverse_type=TableColumnStats.Column_STAT_RELATION_TYPE,
             attributes={}
         )
-        results = [relationship]
-        return results
+        yield relationship
