@@ -3,7 +3,7 @@
 
 import copy
 from typing import (
-    Any, List, Optional,
+    Any, Iterator, Optional,
 )
 
 from databuilder.models.graph_node import GraphNode
@@ -37,7 +37,7 @@ class User(GraphSerializable):
                  email: str,
                  first_name: str = '',
                  last_name: str = '',
-                 name: str = '',
+                 full_name: str = '',
                  github_username: str = '',
                  team_name: str = '',
                  employee_type: str = '',
@@ -54,7 +54,7 @@ class User(GraphSerializable):
 
         :param first_name:
         :param last_name:
-        :param name:
+        :param full_name:
         :param email:
         :param github_username:
         :param team_name:
@@ -71,7 +71,7 @@ class User(GraphSerializable):
         """
         self.first_name = first_name
         self.last_name = last_name
-        self.name = name
+        self.full_name = full_name
 
         self.email = email
         self.github_username = github_username
@@ -89,8 +89,8 @@ class User(GraphSerializable):
         if kwargs:
             self.attrs = copy.deepcopy(kwargs)
 
-        self._node_iter = iter(self.create_nodes())
-        self._rel_iter = iter(self.create_relation())
+        self._node_iter = self._create_node_iterator()
+        self._rel_iter = self._create_relation_iterator()
 
     def create_next_node(self) -> Optional[GraphNode]:
         # return the string representation of the data
@@ -116,18 +116,13 @@ class User(GraphSerializable):
             return ''
         return User.USER_NODE_KEY_FORMAT.format(email=email)
 
-    def create_nodes(self) -> List[GraphNode]:
-        """
-        Create a list of Neo4j node records
-        :return:
-        """
-
+    def get_user_node(self) -> GraphNode:
         node_attributes = {
             User.USER_NODE_EMAIL: self.email,
             User.USER_NODE_IS_ACTIVE: self.is_active,
             User.USER_NODE_FIRST_NAME: self.first_name or '',
             User.USER_NODE_LAST_NAME: self.last_name or '',
-            User.USER_NODE_FULL_NAME: self.name or '',
+            User.USER_NODE_FULL_NAME: self.full_name or '',
             User.USER_NODE_GITHUB_NAME: self.github_username or '',
             User.USER_NODE_TEAM: self.team_name or '',
             User.USER_NODE_EMPLOYEE_TYPE: self.employee_type or '',
@@ -156,9 +151,17 @@ class User(GraphSerializable):
             attributes=node_attributes
         )
 
-        return [node]
+        return node
 
-    def create_relation(self) -> List[GraphRelationship]:
+    def _create_node_iterator(self) -> Iterator[GraphNode]:
+        """
+        Create an user node
+        :return:
+        """
+        user_node = self.get_user_node()
+        yield user_node
+
+    def _create_relation_iterator(self) -> Iterator[GraphRelationship]:
         if self.manager_email:
             # only create the relation if the manager exists
             relationship = GraphRelationship(
@@ -170,10 +173,9 @@ class User(GraphSerializable):
                 reverse_type=User.MANAGER_USER_RELATION_TYPE,
                 attributes={}
             )
-            return [relationship]
-        return []
+            yield relationship
 
     def __repr__(self) -> str:
-        return f'User({self.first_name!r}, {self.last_name!r}, {self.name!r}, {self.email!r}, ' \
+        return f'User({self.first_name!r}, {self.last_name!r}, {self.full_name!r}, {self.email!r}, ' \
                f'{self.github_username!r}, {self.team_name!r}, {self.slack_id!r}, {self.manager_email!r}, ' \
                f'{self.employee_type!r}, {self.is_active!r}, {self.updated_at!r}, {self.role_name!r})'
